@@ -3,7 +3,7 @@
 
 import logging
 from typing import (
-    Any, Dict, List, Optional, Union,
+    Any, Dict, List, Union,
 )
 
 from amundsen_common.models.api import health_check
@@ -41,7 +41,8 @@ class ElasticsearchProxy():
         'column': 'column_names.raw',
         'database': 'database.raw',
         'cluster': 'cluster.raw',
-        'description': 'description'
+        'description': 'description',
+        'resource_type': 'resource_type'
     }
 
     # mapping to translate request for dashboard resources
@@ -54,7 +55,8 @@ class ElasticsearchProxy():
         'product': 'product',
         'tag': 'tags',
         'description': 'description',
-        'last_successful_run_timestamp': 'last_successful_run_timestamp'
+        'last_successful_run_timestamp': 'last_successful_run_timestamp',
+        'resource_type': 'resource_type'
     }
 
     # mapping to translate request for feature resources
@@ -68,14 +70,16 @@ class ElasticsearchProxy():
         'availability': 'availability.raw',
         'tags': 'tags',
         'badges': 'badges',
-        'description': 'description'
+        'description': 'description',
+        'resource_type': 'resource_type'
     }
 
     USER_MAPPING = {
         'full_name': 'full_name',
         'first_name': 'first_name',
         'last_name': 'last_name',
-        'email': 'email'
+        'email': 'email',
+        'resource_type': 'resource_type'
     }
 
     RESOUCE_TO_MAPPING = {
@@ -85,6 +89,40 @@ class ElasticsearchProxy():
         Resource.USER: USER_MAPPING,
     }
 
+    MUST_FIELDS_TABLE = ["name^3",
+                         "name.raw^3",
+                         "schema^2",
+                         "description",
+                         "column_names",
+                         "badges"]
+
+    MUST_FIELDS_DASHBOARD = ["name.raw^75",
+                             "name^7",
+                             "group_name.raw^15",
+                             "group_name^7",
+                             "description^3",
+                             "query_names^3",
+                             "chart_names^2"]
+
+    MUST_FIELDS_FEATURE = ["feature_name.raw^25",
+                           "feature_name^7",
+                           "feature_group.raw^15",
+                           "feature_group^7",
+                           "version^7",
+                           "description^3",
+                           "status",
+                           "entity",
+                           "tags",
+                           "badges"]
+
+    MUST_FIELDS_USER = ["full_name.raw^30",
+                        "full_name^5",
+                        "first_name.raw^5",
+                        "last_name.raw^5",
+                        "first_name^3",
+                        "last_name^3",
+                        "email^3"]
+
     def __init__(self, *,
                  host: str = None,
                  user: str = '',
@@ -116,60 +154,36 @@ class ElasticsearchProxy():
             checks = {f'{type(self).__name__}:connection': {'status': 'Unable to connect'}}
         return health_check.HealthCheck(status=status, checks=checks)
 
-    def _build_term_query(self, resource: Resource, query_term: str) -> Optional[Q]:
+    def _get_must_fields(self, resource: Resource) -> List[str]:
+        must_fields_mapping = {
+            Resource.TABLE: self.MUST_FIELDS_TABLE,
+            Resource.DASHBOARD: self.MUST_FIELDS_DASHBOARD,
+            Resource.FEATURE: self.MUST_FIELDS_FEATURE,
+            Resource.USER: self.MUST_FIELDS_USER
+        }
+
+        return must_fields_mapping[resource]
+
+    def _build_must_query(self, resource: Resource, query_term: str) -> List[Q]:
         """
         Builds the query object for the inputed search term
         """
         if not query_term:
             # We don't want to create multi_match query for ""
             # because it will result in no matches even with filters
-            return None
+            return []
 
-        fields = []
-
-        if resource == Resource.TABLE:
-            fields = ["display_name^1000",
-                      "name.raw^75",
-                      "name^5",
-                      "schema^3",
-                      "description^3",
-                      "column_names^2",
-                      "column_descriptions",
-                      "tags",
-                      "badges",
-                      "programmatic_descriptions"]
-        elif resource == Resource.DASHBOARD:
-            fields = ["name.raw^75",
-                      "name^7",
-                      "group_name.raw^15",
-                      "group_name^7",
-                      "description^3",
-                      "query_names^3",
-                      "chart_names^2"]
-        elif resource == Resource.FEATURE:
-            fields = ["feature_name.raw^25",
-                      "feature_name^7",
-                      "feature_group.raw^15",
-                      "feature_group^7",
-                      "version^7",
-                      "description^3",
-                      "status",
-                      "entity",
-                      "tags",
-                      "badges"]
-        elif resource == Resource.USER:
-            fields = ["full_name.raw^30",
-                      "full_name^5",
-                      "first_name.raw^5",
-                      "last_name.raw^5",
-                      "first_name^3",
-                      "last_name^3",
-                      "email^3"]
-        else:
+        try:
+            fields: List[str] = self._get_must_fields(resource)
+        except KeyError:
             # TODO if you don't specify a resource match for all generic fields in the future
             raise ValueError(f"no fields defined for resource {resource}")
 
-        return MultiMatch(query=query_term, fields=fields, type='most_fields')
+        return [MultiMatch(query=query_term, fields=fields, type='cross_fields')]
+
+    def _build_should_query(self, resource: Resource, query_term: str) -> List[Q]:
+        # Can define on custom es_search_proxy class, no default implementation
+        return []
 
     def _build_filters(self, resource: Resource, filters: List[Filter]) -> List:
         """
@@ -203,20 +217,15 @@ class ElasticsearchProxy():
                                    query_term: str,
                                    filters: List[Filter]) -> Q:
 
-        term_query = self._build_term_query(resource=resource,
+        must_query = self._build_must_query(resource=resource,
                                             query_term=query_term)
+
+        should_query = self._build_should_query(resource=resource,
+                                                query_term=query_term)
+
         filters = self._build_filters(resource=resource, filters=filters)
 
-        es_query = None
-
-        if filters and term_query:
-            es_query = Q(BOOL_QUERY, should=[term_query], filter=filters)
-        elif not filters and term_query:
-            es_query = Q(BOOL_QUERY, should=[term_query])
-        elif filters and not term_query:
-            es_query = Q(BOOL_QUERY, filter=filters)
-        else:
-            raise ValueError("Invalid search query")
+        es_query = Q(BOOL_QUERY, must=must_query, should=should_query, filter=filters)
 
         return es_query
 
@@ -235,7 +244,7 @@ class ElasticsearchProxy():
             if r.success():
                 results_count = r.hits.total.value
                 if results_count > 0:
-                    resource_type = r.hits.hits[0]._type
+                    resource_type = r.hits.hits[0]._source['resource_type']
                     results = []
                     for search_result in r.hits.hits:
                         # mapping gives all the fields in the response
@@ -244,13 +253,17 @@ class ElasticsearchProxy():
                         for f in fields.keys():
                             # remove "raw" from mapping value
                             field = fields[f].split('.')[0]
-                            result_for_field = search_result._source[field]
-                            # AttrList and AttrDict are not json serializable
-                            if type(result_for_field) is AttrList:
-                                result_for_field = list(result_for_field)
-                            elif type(result_for_field) is AttrDict:
-                                result_for_field = result_for_field.to_dict()
-                            result[f] = result_for_field
+                            try:
+                                result_for_field = search_result._source[field]
+                                # AttrList and AttrDict are not json serializable
+                                if type(result_for_field) is AttrList:
+                                    result_for_field = list(result_for_field)
+                                elif type(result_for_field) is AttrDict:
+                                    result_for_field = result_for_field.to_dict()
+                                result[f] = result_for_field
+                            except KeyError:
+                                logging.debug(f'Field: {field} missing in search response.')
+                                pass
                         result["search_score"] = search_result._score
                         results.append(result)
                     # replace empty results with actual results
@@ -310,6 +323,7 @@ class ElasticsearchProxy():
         responses = self.execute_queries(queries=queries,
                                          page_index=page_index,
                                          results_per_page=results_per_page)
+        print(responses)
 
         formatted_response = self._format_response(page_index=page_index,
                                                    results_per_page=results_per_page,
